@@ -42,7 +42,7 @@ async def hive_http_callback(request: Request, chat, title, at_users=None, image
         chat=chat,
         title=title,
         subtitle='',
-        df=df.to_dict('r'),
+        df=df,
         image_desc=image_desc
     )
 
